import setuptools

setuptools.setup(
  name = 'algo-square',         
  version = '0.0.1',      
  description = '',
  long_description = '',  
  author = 'AlgoSquare Contributors',                 
  author_email = 'dev@algosquare.ai',     
  url = 'https://algosquare.ai',   
  packages=[],
  install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
